@@ -76,7 +76,7 @@ _gss_asn1_get_length_der (const unsigned char *der, int *len)
       k = der[0] & 0x7F;
       punt = 1;
       ans = 0;
-      while (punt <= k && *len < punt)
+      while (punt <= k && punt < *len)
 	ans = ans * 256 + der[punt++];
 
       *len = punt;
@@ -99,10 +99,7 @@ _gss_encapsulate_token (char *oid, size_t oidlen,
   _gss_asn1_length_der(asn1len, NULL, &asn1lenlen);
 
   *outlen = 1 + asn1lenlen + asn1len;
-  p = malloc(*outlen);
-  if (!p)
-    return 0;
-
+  p = xmalloc(*outlen);
   *out = p;
 
   *p++ = '\x60';
@@ -131,6 +128,33 @@ gss_encapsulate_token (gss_buffer_t input_message,
 				 &output_message->length);
 }
 
+int
+gss_encapsulate_token_prefix (gss_buffer_t input_message,
+			      char *prefix, size_t prefixlen,
+			      gss_OID token_oid,
+			      gss_buffer_t output_message)
+{
+  char *in;
+  size_t inlen;
+  int rc;
+
+  inlen = prefixlen + input_message->length;
+  in = xmalloc(inlen);
+  memcpy(in, prefix, prefixlen);
+  memcpy(in + prefixlen, input_message->value, input_message->length);
+
+  rc = _gss_encapsulate_token (token_oid->elements,
+			       token_oid->length,
+			       in,
+			       inlen,
+			       &output_message->value,
+			       &output_message->length);
+
+  free(in);
+
+  return rc;
+}
+
 static int
 _gss_decapsulate_token (char *in, size_t inlen,
 			char **oid, size_t *oidlen,
@@ -172,18 +196,14 @@ _gss_decapsulate_token (char *in, size_t inlen,
     return 0;
 
   *oidlen = asn1lenlen;
-  *oid = malloc(*oidlen);
-  if (!*oid)
-    return 0;
+  *oid = xmalloc(*oidlen);
   memcpy(*oid, in, *oidlen);
 
   inlen -= asn1lenlen;
   in += asn1lenlen;
 
   *outlen = inlen;
-  *out = malloc(*outlen);
-  if (!*out)
-    return 0;
+  *out = xmalloc(*outlen);
   memcpy(*out, in, *outlen);
 
   return 1;
