@@ -22,6 +22,7 @@
 #include "internal.h"
 #include "krb5.h"
 
+#include "xgethostname.h"
 #include <shishi.h>
 
 typedef struct _gss_krb5_cred_struct
@@ -263,36 +264,6 @@ gss_krb5_init_sec_context (OM_uint32 * minor_status,
   return GSS_S_FAILURE;
 }
 
-/* A gethostname() replacement that always return a zero terminated string. */
-static char *
-xgethostname (void)
-{
-  char *hostname;
-  size_t size;
-
-  size = 42;
-  /* Use size + 1 here rather than size to work around the bug
-     in SunOS5.5's gethostname whereby it NUL-terminates HOSTNAME
-     even when the name is longer than the supplied buffer.  */
-  hostname = xmalloc (size + 1);
-  while (size < 1000)
-    {
-      int k = size - 1;
-      int err;
-
-      hostname[k] = '\0';
-      err = gethostname (hostname, size);
-      if (err >= 0 && hostname[k] == '\0')
-	return hostname;
-      size *= 2;
-      hostname = xrealloc (hostname, size + 1);
-    }
-
-  strcat(hostname, "localhost");
-
-  return hostname;
-}
-
 OM_uint32
 gss_krb5_canonicalize_name (OM_uint32 * minor_status,
 			    const gss_name_t input_name,
@@ -676,7 +647,7 @@ gss_krb5_unwrap (OM_uint32 * minor_status,
 				      cksum, 8,
 				      p, 8,
 				      &t, &i);
-	if (rc != SHISHI_OK || i != 20)
+	if (rc != SHISHI_OK || i != 8)
 	  return GSS_S_FAILURE;
 
 	memcpy(p, t, i);
@@ -792,7 +763,7 @@ gss_krb5_display_status (OM_uint32 * minor_status,
   switch (status_value)
     {
     case 0:
-      status_string->value = strdup(_("No krb5 error"));
+      status_string->value = xstrdup(_("No krb5 error"));
       status_string->length = strlen(status_string->value);
       break;
 
@@ -815,12 +786,12 @@ gss_krb5_display_status (OM_uint32 * minor_status,
     case GSS_KRB5_S_KG_BAD_SIGN_TYPE:
     case GSS_KRB5_S_KG_BAD_LENGTH:
     case GSS_KRB5_S_KG_CTX_INCOMPLETE:
-      status_string->value = strdup(_(gss_krb5_errors[status_value-1].text));
+      status_string->value = xstrdup(_(gss_krb5_errors[status_value-1].text));
       status_string->length = strlen(status_string->value);
       break;
 
     default:
-      status_string->value = strdup(_("Unknown krb5 error"));
+      status_string->value = xstrdup(_("Unknown krb5 error"));
       status_string->length = strlen(status_string->value);
       break;
     }
