@@ -139,6 +139,9 @@ gss_test_oid_set_member (OM_uint32 * minor_status,
 
   *present = 0;
 
+  if (member == GSS_C_NO_OID)
+    return GSS_S_COMPLETE;
+
   for (i = 0, cur = set->elements; i < set->count; i++, cur++)
     {
       if (cur->length == member->length &&
@@ -161,6 +164,9 @@ gss_release_oid_set (OM_uint32 * minor_status, gss_OID_set * set)
   if (minor_status)
     *minor_status = 0;
 
+  if (!set || *set == GSS_C_NO_OID_SET)
+    return GSS_S_COMPLETE;
+
   for (i = 0, cur = (*set)->elements; i < (*set)->count; i++, cur++)
     free(cur->elements);
 
@@ -172,7 +178,32 @@ gss_release_oid_set (OM_uint32 * minor_status, gss_OID_set * set)
 
 /* See error.c for gss_display_status() */
 
-/* See meta.c for gss_indicate_mechs() */
+OM_uint32
+gss_indicate_mechs (OM_uint32 * minor_status, gss_OID_set * mech_set)
+{
+  OM_uint32 maj_stat;
+  gss_OID_set oids;
+  int i;
+
+  maj_stat = gss_create_empty_oid_set (minor_status, mech_set);
+  if (maj_stat != GSS_S_COMPLETE)
+    return maj_stat;
+
+  for (i = 0; _gss_mech_apis[i].mech; i++)
+    {
+      maj_stat = gss_add_oid_set_member (minor_status, _gss_mech_apis[i].mech,
+					 mech_set);
+      if (maj_stat != GSS_S_COMPLETE)
+	{
+	  gss_release_oid_set (minor_status, mech_set);
+	  return maj_stat;
+	}
+    }
+
+  if (minor_status)
+    *minor_status = 0;
+  return GSS_S_COMPLETE;
+}
 
 OM_uint32
 gss_release_buffer (OM_uint32 * minor_status, gss_buffer_t buffer)
